@@ -125,6 +125,93 @@ OC.L10N.register(
     "{email} tried to request the password to access {file}" : "{email} forsøgte at anmode om adgangskoden til {file}",
     "Someone is requesting the password to access {file}" : "Nogen beder om adgangskoden til {file}",
     "Someone tried to request the password to access {file}" : "Nogen forsøgte at bede om adgangskoden til {file}",
+    "Open settings" : "Indstillinger",
+    "Andorra" : "Andorra",
+    "Afghanistan" : "Afghanistan",
+    "Albania" : "Albanien",
+    "Armenia" : "Armenien",
+    "Angola" : "Angola",
+    "Argentina" : "Argentina",
+    "Austria" : "Østrig",
+    "Australia" : "Australien",
+    "Bangladesh" : "Bangladesh",
+    "Belgium" : "Belgien",
+    "Burkina Faso" : "Burkina Faso",
+    "Bulgaria" : "Bulgarien",
+    "Bahrain" : "Bahrain",
+    "Bermuda" : "Bermuda",
+    "Brazil" : "Brasilien",
+    "Bahamas" : "Bahamas",
+    "Canada" : "Canada",
+    "Chile" : "Chile",
+    "China" : "Kina",
+    "Cuba" : "Cuba",
+    "Germany" : "Tyskland",
+    "Denmark" : "Danmark",
+    "Algeria" : "Algeriet",
+    "Ecuador" : "Ecuador",
+    "Egypt" : "Egypten",
+    "Eritrea" : "Eritrea",
+    "Spain" : "Spanien",
+    "Finland" : "Finland",
+    "Fiji" : "Fiji",
+    "Faroe Islands" : "Færøerne",
+    "France" : "Frankrig",
+    "Ghana" : "Ghana",
+    "Gibraltar" : "Gibraltar",
+    "Greenland" : "Grønland",
+    "Guinea" : "Guinea",
+    "Greece" : "Grækenland",
+    "Guatemala" : "Guatemala",
+    "Hong Kong" : "Hong Kong",
+    "Honduras" : "Honduras",
+    "Croatia" : "Kroatien",
+    "Haiti" : "Haiti",
+    "Hungary" : "Ungarn",
+    "Indonesia" : "Indonesien",
+    "Ireland" : "Irland",
+    "Israel" : "Israel",
+    "India" : "Indien",
+    "Iraq" : "Irak",
+    "Iceland" : "Island",
+    "Italy" : "Italien",
+    "Jamaica" : "Jamaica",
+    "Japan" : "Japan",
+    "Kenya" : "Kenya",
+    "Kuwait" : "Kuwait",
+    "Liechtenstein" : "Liechtenstein",
+    "Luxembourg" : "Luxembourg",
+    "Montenegro" : "Montenegro",
+    "Namibia" : "Namibia",
+    "Norway" : "Norge",
+    "Nepal" : "Nepal",
+    "New Zealand" : "New Zealand",
+    "Oman" : "Oman",
+    "Panama" : "Panama",
+    "Peru" : "Peru",
+    "Pakistan" : "Pakistan",
+    "Poland" : "Polen",
+    "Portugal" : "Portugal",
+    "Qatar" : "Qatar",
+    "Romania" : "Rumænien",
+    "Rwanda" : "Rwanda",
+    "Sudan" : "Sudan",
+    "Sweden" : "Sverige",
+    "Singapore" : "Singapore",
+    "Slovenia" : "Slovenien",
+    "Slovakia" : "Slovakiet",
+    "Senegal" : "Senegal",
+    "Somalia" : "Somalia",
+    "Chad" : "Chad",
+    "Thailand" : "Thailand",
+    "Tunisia" : "Tunesien",
+    "Turkey" : "Tyrkiet",
+    "Ukraine" : "Ukraine",
+    "Uganda" : "Uganda",
+    "Samoa" : "Samoa",
+    "Yemen" : "Yemen",
+    "South Africa" : "Sydafrika",
+    "Zimbabwe" : "Zimbabwe",
     "Invalid date, date format must be YYYY-MM-DD" : "Ugyldig dato. Brug formatet ÅÅÅ-MM-DD",
     "Conversation not found" : "Samtalen blev ikke fundet",
     "Path is already shared with this room" : "Stien er allerede delt med dette rum",
@@ -170,6 +257,14 @@ OC.L10N.register(
     "All messages" : "Alle beskeder",
     "@-mentions only" : "Kun når nævnt med @",
     "Off" : "Slået fra",
+    "Language" : "Sprog",
+    "Country" : "Land",
+    "Status" : "Status",
+    "Created at" : "Oprettet",
+    "Pending" : "Afventer",
+    "Error" : "Fejl",
+    "Blocked" : "Blokeret",
+    "Expired" : "Udløbet",
     "Signaling server URL" : "Signalserver URL",
     "Validate SSL certificate" : "Godkend SSL certifikat",
     "Delete this server" : "Slet denne server",
@@ -202,6 +297,7 @@ OC.L10N.register(
     "Share a single window" : "Del et vindue",
     "Show your screen" : "Vis din skærm",
     "Stop screensharing" : "Stop skærmdeling",
+    "Dismiss" : "Afvis",
     "No audio" : "Ingen lyd",
     "Mute audio (m)" : "Slå lyden fra (m)",
     "Unmute audio (m)" : "Slå lyden til (m)",
@@ -256,7 +352,6 @@ OC.L10N.register(
     "Copy conversation link" : "Kopier samtalelink",
     "Error while creating the conversation" : "Fejl under oprettelse af samtalen",
     "Link copied to the clipboard!" : "Link kopieret til udklipsholderen!",
-    "Error" : "Fejl",
     "Create a new group conversation" : "Opret en ny gruppesamtale",
     "Password protect" : "Beskyt med adgangskode",
     "Add participants" : "Tilføj deltagere",
@@ -302,7 +397,6 @@ OC.L10N.register(
     "Display name: " : "Vist navn:",
     "Edit" : "Rediger",
     "Start call" : "Start opkald",
-    "Dismiss" : "Afvis",
     "Go to file" : "Gå til fil",
     "Rename conversation" : "Omdøb samtale",
     "Share link" : "Del link",
