@@ -20,6 +20,7 @@ OC.L10N.register(
     "{user} invited you to a group conversation: {call}" : "{user} invited you to a group conversation: {call}",
     "{user} wants to talk with you" : "{user} wants to talk with you",
     "A group call has started in {call}" : "A group call has started in {call}",
+    "Open settings" : "Open settings",
     "Invalid date, date format must be YYYY-MM-DD" : "Invalid date, date format must be YYYY-MM-DD",
     "Leave call" : "Leave call",
     "This conversation has ended" : "This conversation has ended",
@@ -35,6 +36,14 @@ OC.L10N.register(
     "Name" : "Name",
     "General settings" : "General settings",
     "Off" : "Off",
+    "Language" : "Language",
+    "Country" : "Country",
+    "Status" : "Status",
+    "Created at" : "Created at",
+    "Pending" : "Pending",
+    "Error" : "Error",
+    "Blocked" : "Blocked",
+    "Expired" : "Expired",
     "Validate SSL certificate" : "Validate SSL certificate",
     "Saved" : "Saved",
     "Shared secret" : "Shared secret",
@@ -51,6 +60,7 @@ OC.L10N.register(
     "Share this link to invite others!" : "Share this link to invite others!",
     "Show your screen" : "Show your screen",
     "Stop screensharing" : "Stop screensharing",
+    "Dismiss" : "Dismiss",
     "No audio" : "No audio",
     "Mute audio (m)" : "Mute audio (m)",
     "Unmute audio (m)" : "Unmute audio (m)",
@@ -77,7 +87,6 @@ OC.L10N.register(
     "Loading" : "Loading",
     "Groups" : "Groups",
     "Circles" : "Circles",
-    "Error" : "Error",
     "Password protect" : "Password protect",
     "Back" : "Back",
     "Close" : "Close",
@@ -98,7 +107,6 @@ OC.L10N.register(
     "Chat" : "Chat",
     "Settings" : "Settings",
     "Edit" : "Edit",
-    "Dismiss" : "Dismiss",
     "Rename conversation" : "Rename conversation",
     "Share link" : "Share link",
     "Password protection" : "Password protection",
