@@ -94,6 +94,52 @@ OC.L10N.register(
     "Call back" : "Soita takaisin",
     "You missed a call from {user}" : "Sinulta jäi vastaamatta puhelu käyttäjältä {user}",
     "A group call has started in {call}" : "Ryhmäpuhelu on alkanut puhelussa {call}",
+    "Open settings" : "Avaa asetukset",
+    "Austria" : "Itävalta",
+    "Belgium" : "Belgia",
+    "Bulgaria" : "Bulgaria",
+    "Brazil" : "Brasilia",
+    "Canada" : "Kanada",
+    "Switzerland" : "Sveitsi",
+    "Chile" : "Chile",
+    "China" : "Kiina",
+    "Cuba" : "Kuuba",
+    "Cyprus" : "Kypros",
+    "Germany" : "Saksa",
+    "Denmark" : "Tanska",
+    "Estonia" : "Viro",
+    "Egypt" : "Egypti",
+    "Spain" : "Espanja",
+    "Finland" : "Suomi",
+    "France" : "Ranska",
+    "Greece" : "Kreikka",
+    "Croatia" : "Kroatia",
+    "Haiti" : "Haiti",
+    "Hungary" : "Unkari",
+    "Ireland" : "Irlanti",
+    "India" : "Intia",
+    "Iraq" : "Irak",
+    "Iceland" : "Islanti",
+    "Italy" : "Italia",
+    "Japan" : "Japani",
+    "Kenya" : "Kenia",
+    "Lithuania" : "Liettua",
+    "Latvia" : "Latvia",
+    "Montenegro" : "Montenegro",
+    "Norway" : "Norja",
+    "Panama" : "Panama",
+    "Peru" : "Peru",
+    "Poland" : "Puola",
+    "Portugal" : "Portugali",
+    "Romania" : "Romania",
+    "Sweden" : "Ruotsi",
+    "Singapore" : "Singapore",
+    "Slovakia" : "Slovakia",
+    "Somalia" : "Somalia",
+    "Thailand" : "Thaimaa",
+    "Tunisia" : "Tunisia",
+    "Turkey" : "Turkki",
+    "Ukraine" : "Ukraina",
     "Invalid date, date format must be YYYY-MM-DD" : "Virheellinen päiväys, päiväyksen muoto tulee olla YYYY-MM-DD",
     "Conversation not found" : "Keskustelua ei löydy",
     "Path is already shared with this room" : "Polku on jo jaettu tämän huoneen kesken",
@@ -128,6 +174,15 @@ OC.L10N.register(
     "All messages" : "Kaikki viestit",
     "@-mentions only" : "Vain @-maininnat",
     "Off" : "Pois",
+    "Language" : "Kieli",
+    "Country" : "Maa",
+    "Status" : "Tila",
+    "Created at" : "Luotu",
+    "Pending" : "Odottaa",
+    "Error" : "Virhe",
+    "Blocked" : "Estetty",
+    "Active" : "Aktiivinen",
+    "Expired" : "Vanhentunut",
     "Validate SSL certificate" : "Vahvista SSL-varmenne",
     "Delete this server" : "Poista tämä palvelin",
     "Saved" : "Tallennettu",
@@ -153,6 +208,7 @@ OC.L10N.register(
     "Share a single window" : "Jaa yksittäinen ikkuna",
     "Show your screen" : "Näytä oma näyttösi",
     "Stop screensharing" : "Lopeta näytön jakaminen",
+    "Dismiss" : "Hylkää",
     "No audio" : "Ei ääntä",
     "Mute audio (m)" : "Mykistä äänet (m)",
     "Unmute audio (m)" : "Palauta äänet (m)",
@@ -199,7 +255,6 @@ OC.L10N.register(
     "Copy conversation link" : "Kopioi keskustelulinkki",
     "Error while creating the conversation" : "Virhe keskustelua luotaessa",
     "Link copied to the clipboard!" : "Linkki kopioitu leikepöydälle!",
-    "Error" : "Virhe",
     "Create a new group conversation" : "Luo uusi ryhmäkeskustelu",
     "Password protect" : "Suojaa salasanalla",
     "Add participants" : "Lisää osallistujat",
@@ -241,7 +296,6 @@ OC.L10N.register(
     "Display name: " : "Näyttönimi:",
     "Edit" : "Muokkaa",
     "Start call" : "Aloita puhelu",
-    "Dismiss" : "Hylkää",
     "Go to file" : "Siirry tiedostoon",
     "Rename conversation" : "Nimeä keskustelu uudelleen",
     "Share link" : "Jaa linkki",
