@@ -60,6 +60,247 @@ OC.L10N.register(
     "Join call" : "הצטרפות לשיחה",
     "{user} invited you to a group conversation: {call}" : "הוזמנת על ידי {user} לדיון קבוצתי: {call}",
     "A group call has started in {call}" : "החלה שיחה קבוצתית תחת {call}",
+    "Open settings" : "פתיחת הגדרות",
+    "Andorra" : "אנדורה",
+    "United Arab Emirates" : "איחוד האמירויות הערביות",
+    "Afghanistan" : "אפגניסטן",
+    "Antigua and Barbuda" : "אנטיגואה וברבודה",
+    "Anguilla" : "אנגווילה",
+    "Albania" : "אלבניה",
+    "Armenia" : "ארמניה",
+    "Angola" : "אנגולה",
+    "Antarctica" : "אנטארקטיקה",
+    "Argentina" : "ארגנטינה",
+    "American Samoa" : "סמואה האמריקנית",
+    "Austria" : "אוסטריה",
+    "Australia" : "אוסטרליה",
+    "Aruba" : "ארובה",
+    "Åland Islands" : "איי אולנד",
+    "Azerbaijan" : "אזרבייג׳ן",
+    "Bosnia and Herzegovina" : "בוסניה והרצגובינה",
+    "Barbados" : "ברבדוס",
+    "Bangladesh" : "בנגלדש",
+    "Belgium" : "בלגיה",
+    "Burkina Faso" : "בורקינה פאסו",
+    "Bulgaria" : "בולגריה",
+    "Bahrain" : "בחריין",
+    "Burundi" : "בורונדי",
+    "Benin" : "בנין",
+    "Saint Barthélemy" : "סן ברתלמי",
+    "Bermuda" : "ברמודה",
+    "Brunei Darussalam" : "ברוניי משכן השלום",
+    "Bonaire, Sint Eustatius and Saba" : "בונייר, סנט אוסטתיוס וסאבא",
+    "Brazil" : "ברזיל",
+    "Bahamas" : "איי בהאמה",
+    "Bhutan" : "בהוטן",
+    "Bouvet Island" : "האי בּוּבֶה",
+    "Botswana" : "בוטסואנה",
+    "Belarus" : "בלרוס",
+    "Belize" : "בליז",
+    "Canada" : "קנדה",
+    "Cocos (Keeling) Islands" : "איי קוקוס קילינג",
+    "Central African Republic" : "הרפובליקה המרכז-אפריקאית",
+    "Congo" : "קונגו",
+    "Switzerland" : "שווייץ",
+    "Côte d'Ivoire" : "קוט דיוואר (חוף השנהב)",
+    "Cook Islands" : "איי קוק",
+    "Chile" : "צ׳ילה",
+    "Cameroon" : "קמרון",
+    "China" : "סין",
+    "Colombia" : "קולומביה",
+    "Costa Rica" : "קוסטה ריקה",
+    "Cuba" : "קובה",
+    "Cabo Verde" : "כף ורדה",
+    "Curaçao" : "קוראסאו",
+    "Christmas Island" : "אי חג המולד",
+    "Cyprus" : "קפריסין",
+    "Czechia" : "צ׳כיה",
+    "Germany" : "גרמניה",
+    "Djibouti" : "ג׳יבוטי",
+    "Denmark" : "דנמרק",
+    "Dominica" : "דומיניקה",
+    "Dominican Republic" : "הרפובליקה הדומיניקנית",
+    "Algeria" : "אלג׳יריה",
+    "Ecuador" : "אקוודור",
+    "Estonia" : "אסטוניה",
+    "Egypt" : "מצרים",
+    "Western Sahara" : "סהרה המערבית",
+    "Eritrea" : "אריתריאה",
+    "Spain" : "ספרד",
+    "Ethiopia" : "אתיופיה",
+    "Finland" : "פינלנד",
+    "Fiji" : "פיג׳י",
+    "Falkland Islands (Malvinas)" : "איי פוקלנד (מלווינאס)",
+    "Faroe Islands" : "איי פארו",
+    "France" : "צרפת",
+    "Gabon" : "גבון",
+    "United Kingdom of Great Britain and Northern Ireland" : "הממלכה המאוחדת של בריטניה הגדולה וצפון אירלנד",
+    "Grenada" : "גרנדה",
+    "Georgia" : "גאורגיה",
+    "French Guiana" : "גיאנה הצרפתית",
+    "Guernsey" : "גרנזי",
+    "Ghana" : "גאנה",
+    "Gibraltar" : "גיברלטר",
+    "Greenland" : "גרינלנד",
+    "Gambia" : "גמביה",
+    "Guinea" : "גינאה",
+    "Guadeloupe" : "גוואדלופ",
+    "Equatorial Guinea" : "גינאה המשוונית",
+    "Greece" : "יוון",
+    "South Georgia and the South Sandwich Islands" : "איי ג׳ורג׳יה הדרומית ואיי סנדוויץ׳ הדרומיים",
+    "Guatemala" : "גואטמלה",
+    "Guam" : "גואם",
+    "Guinea-Bissau" : "גינאה ביסאו",
+    "Guyana" : "גיאנה",
+    "Hong Kong" : "הונג קונג",
+    "Heard Island and McDonald Islands" : "האי הרד ואיי מקדונלד",
+    "Honduras" : "הונדורס",
+    "Croatia" : "קרואטיה",
+    "Haiti" : "האיטי",
+    "Hungary" : "הונגריה",
+    "Indonesia" : "אינדונזיה",
+    "Ireland" : "אירלנד",
+    "Israel" : "ישראל",
+    "Isle of Man" : "האי מאן",
+    "India" : "הודו",
+    "British Indian Ocean Territory" : "הטריטוריה הבריטית באוקיינוס ההודי",
+    "Iraq" : "עיראק",
+    "Iceland" : "איסלנד",
+    "Italy" : "איטליה",
+    "Jersey" : "ג׳רזי",
+    "Jamaica" : "ג׳מייקה",
+    "Jordan" : "ירדן",
+    "Japan" : "יפן",
+    "Kenya" : "קניה",
+    "Kyrgyzstan" : "קירגיסטן",
+    "Cambodia" : "קמבודיה",
+    "Kiribati" : "קיריבטי",
+    "Comoros" : "קומורוס",
+    "Saint Kitts and Nevis" : "סנט קיטס ונוויס",
+    "Korea, Republic of" : "קוריאה, הרפובליקה של",
+    "Kuwait" : "כווית",
+    "Cayman Islands" : "איי קיימן",
+    "Kazakhstan" : "קזחסטן",
+    "Lao People's Democratic Republic" : "הרפובליקה הדמוקרטית העממית של אנשי הלאו",
+    "Lebanon" : "לבנון",
+    "Saint Lucia" : "סנט לוסיה",
+    "Liechtenstein" : "ליכטנשטיין",
+    "Sri Lanka" : "סרי לנקה",
+    "Liberia" : "ליבריה",
+    "Lesotho" : "לסוטו",
+    "Lithuania" : "ליטא",
+    "Luxembourg" : "לוקסמבורג",
+    "Latvia" : "לטביה",
+    "Libya" : "לוב",
+    "Morocco" : "מרוקו",
+    "Monaco" : "מונקו",
+    "Moldova, Republic of" : "מודלובה, הרפובליקה של",
+    "Montenegro" : "מונטנגרו",
+    "Saint Martin (French part)" : "סן מרטן (העבר הצרפתי)",
+    "Madagascar" : "מדגסקר",
+    "Marshall Islands" : "איי מרשל",
+    "Mali" : "מאלי",
+    "Myanmar" : "מיאנמר",
+    "Mongolia" : "מונגוליה",
+    "Macao" : "מקאו",
+    "Northern Mariana Islands" : "איי מריאנה הצפוניים",
+    "Martinique" : "מרטיניק",
+    "Mauritania" : "מאוריטניה",
+    "Montserrat" : "מונטסראט",
+    "Malta" : "מלטא",
+    "Mauritius" : "מאוריציוס",
+    "Maldives" : "האיים המלדיביים",
+    "Malawi" : "מלאווי",
+    "Mexico" : "מקסיקו",
+    "Malaysia" : "מלזיה",
+    "Mozambique" : "מוזמביק",
+    "Namibia" : "נמיביה",
+    "New Caledonia" : "קלדוניה החדשה",
+    "Niger" : "ניז׳ר",
+    "Norfolk Island" : "האי נורפוק",
+    "Nigeria" : "ניגריה",
+    "Nicaragua" : "ניקרגואה",
+    "Netherlands" : "הולנד",
+    "Norway" : "נורווגיה",
+    "Nepal" : "נפאל",
+    "Nauru" : "נאורו",
+    "Niue" : "ניואה",
+    "New Zealand" : "ניו זילנד",
+    "Oman" : "עומאן",
+    "Panama" : "פנמה",
+    "Peru" : "פרו",
+    "French Polynesia" : "פולינזיה הצרפתית",
+    "Papua New Guinea" : "פפואה גינאה החדשה",
+    "Philippines" : "הפיליפינים",
+    "Pakistan" : "פקיסטן",
+    "Poland" : "פולין",
+    "Saint Pierre and Miquelon" : "סן-פייר ומיקלון",
+    "Pitcairn" : "פיטקרן",
+    "Puerto Rico" : "פוארטו ריקו",
+    "Palestine, State of" : "הרשות הפלסטינית",
+    "Portugal" : "פורטוגל",
+    "Palau" : "פלאו",
+    "Paraguay" : "פרגוואי",
+    "Qatar" : "קטאר",
+    "Réunion" : "ראוניון",
+    "Romania" : "רומניה",
+    "Serbia" : "סרביה",
+    "Russian Federation" : "הפדרציה הרוסית",
+    "Rwanda" : "רואנדה",
+    "Saudi Arabia" : "ערב הסעודית",
+    "Solomon Islands" : "איי שלמה",
+    "Seychelles" : "איי סיישל",
+    "Sudan" : "סודאן",
+    "Sweden" : "שוודיה",
+    "Singapore" : "סינגפור",
+    "Saint Helena, Ascension and Tristan da Cunha" : "סנט הלנה, אסנשן וטריסטן דה קונה",
+    "Slovenia" : "סלובניה",
+    "Svalbard and Jan Mayen" : "סבאלברד ויאן מאיין",
+    "Slovakia" : "סלובקיה",
+    "Sierra Leone" : "סיירה לאון",
+    "San Marino" : "סן מרינו",
+    "Senegal" : "סנגל",
+    "Somalia" : "סומליה",
+    "Suriname" : "סורינאם",
+    "South Sudan" : "דרום סודאן",
+    "Sao Tome and Principe" : "סאו טומה ופרינסיפה",
+    "El Salvador" : "אל סלוודור",
+    "Sint Maarten (Dutch part)" : "סנט מארטן (העבר ההולנדי)",
+    "Syrian Arab Republic" : "הרפובליקה הערבית הסורית",
+    "Eswatini" : "אסוואטיני",
+    "Turks and Caicos Islands" : "איי טרקס וקייקוס",
+    "Chad" : "צ׳אד",
+    "French Southern Territories" : "הארצות הדרומיות והאנטארקטיות של צרפת",
+    "Togo" : "טוגו",
+    "Thailand" : "תאילנד",
+    "Tajikistan" : "טג׳יקיסטן",
+    "Tokelau" : "טוקלאו",
+    "Timor-Leste" : "מזרח טימור",
+    "Turkmenistan" : "טורקמניסטן",
+    "Tunisia" : "תוניסיה",
+    "Tonga" : "טונגאית",
+    "Turkey" : "טורקיה",
+    "Trinidad and Tobago" : "טרינידד וטובגו",
+    "Tuvalu" : "טובאלו",
+    "Taiwan, Province of China" : "טאיוואן (מחוז סיני)",
+    "Tanzania, United Republic of" : "טנזניה, הרפובליקה המאוחדת של",
+    "Ukraine" : "אוקראינה",
+    "Uganda" : "אוגנדה",
+    "United States Minor Outlying Islands" : "האיים המרוחקים הקטנים של ארה״ב",
+    "United States of America" : "ארצות הברית",
+    "Uruguay" : "אורוגוואי",
+    "Uzbekistan" : "אוזבקיסטן",
+    "Holy See" : "הכס הקדוש",
+    "Saint Vincent and the Grenadines" : "סנט וינסנט והגרנדינים",
+    "Viet Nam" : "וייטנאם",
+    "Vanuatu" : "ונואטו",
+    "Wallis and Futuna" : "ואליס ופוטונה",
+    "Samoa" : "סמואה",
+    "Yemen" : "תימן",
+    "Mayotte" : "מָיוֹט",
+    "South Africa" : "דרום אפריקה",
+    "Zambia" : "זמביה",
+    "Zimbabwe" : "זימבבואה",
     "Invalid date, date format must be YYYY-MM-DD" : "תאריך לא חוקי, תבנית התאריך חייבת להיות YYYY-MM-DD",
     "Navigating away from the page will leave the call in {conversation}" : "ניווט מחוץ לעמוד תנתק את השיחה שב־{conversation}",
     "Leave call" : "יציאה מהשיחה",
@@ -94,6 +335,15 @@ OC.L10N.register(
     "Enabled for" : "מופעל עבור",
     "General settings" : "הגדרות כלליות",
     "Off" : "כבוי",
+    "Language" : "שפה",
+    "Country" : "מדינה",
+    "Status" : "מצב",
+    "Created at" : "נוצר ב־",
+    "Pending" : "בהמתנה",
+    "Error" : "שגיאה",
+    "Blocked" : "נחסם",
+    "Active" : "פעיל",
+    "Expired" : "פג",
     "Validate SSL certificate" : "אימות אישור SSL",
     "Saved" : "נשמר",
     "Shared secret" : "סוד משותף",
@@ -112,6 +362,7 @@ OC.L10N.register(
     "Share this link to invite others!" : "יש לשתף את הקישור הזה כדי להזמין אחרים!",
     "Show your screen" : "הצגת המסך שלך",
     "Stop screensharing" : "הפסקת שיתוף המסך",
+    "Dismiss" : "התעלמות",
     "No audio" : "אין שמע",
     "Mute audio (m)" : "השתקת שמע (m)",
     "Unmute audio (m)" : "ביטול השקת שמע (m)",
@@ -149,7 +400,6 @@ OC.L10N.register(
     "Copy conversation link" : "העתקת קישור דיון",
     "Error while creating the conversation" : "שגיאה ביצירת הדיון",
     "Link copied to the clipboard!" : "הקישור הועתק ללוח הגזירים!",
-    "Error" : "שגיאה",
     "Create a new group conversation" : "יצירת דיון קבוצתי חדש",
     "Password protect" : "הגנה בססמה",
     "Add participants" : "הוספת משתתפים",
@@ -196,7 +446,6 @@ OC.L10N.register(
     "Display name: " : "שם תצוגה:",
     "Edit" : "עריכה",
     "Start call" : "התחלת שיחה",
-    "Dismiss" : "התעלמות",
     "Go to file" : "מעבר לקובץ",
     "Rename conversation" : "שינוי שם הדיון",
     "Share link" : "שיתוף קישור",
