@@ -93,6 +93,247 @@ OC.L10N.register(
     "{user} wants to talk with you" : "{user} vill tala við þig",
     "Call back" : "Hringja til baka",
     "A group call has started in {call}" : "Hópsímtal er byrjað í {call}",
+    "Open settings" : "Opna stillingar",
+    "Andorra" : "Andorra",
+    "United Arab Emirates" : "Sameinuðu arabísku furstadæmin",
+    "Afghanistan" : "Afganistan",
+    "Antigua and Barbuda" : "Antígva og Barbúda",
+    "Anguilla" : "Anguilla",
+    "Albania" : "Albanía",
+    "Armenia" : "Armenía",
+    "Angola" : "Angóla",
+    "Antarctica" : "Suðurskautslandið",
+    "Argentina" : "Argentína",
+    "American Samoa" : "Bandarísku Samóaeyjar",
+    "Austria" : "Austurríki",
+    "Australia" : "Ástralía",
+    "Aruba" : "Arúba",
+    "Åland Islands" : "Álandseyjar",
+    "Azerbaijan" : "Aserbaídsjan",
+    "Bosnia and Herzegovina" : "Bosnía og Herzegónía",
+    "Barbados" : "Barbados",
+    "Bangladesh" : "Bangladess",
+    "Belgium" : "Belgía",
+    "Burkina Faso" : "Búrkína Fasó",
+    "Bulgaria" : "Búlgaría",
+    "Bahrain" : "Barein",
+    "Burundi" : "Búrúndí",
+    "Benin" : "Benín",
+    "Saint Barthélemy" : "Saint Barthélemy",
+    "Bermuda" : "Bermúda",
+    "Brunei Darussalam" : "Brúnei Darussalam",
+    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sankti Eustatius og Saba",
+    "Brazil" : "Brasilía",
+    "Bahamas" : "Bahamaeyjar",
+    "Bhutan" : "Bútan",
+    "Bouvet Island" : "Bouvet eyja",
+    "Botswana" : "Botsvana",
+    "Belarus" : "Hvíta-Rússland",
+    "Belize" : "Belís",
+    "Canada" : "Kanada",
+    "Cocos (Keeling) Islands" : "Kókoseyjar",
+    "Central African Republic" : "Mið-Afríkulýðveldið",
+    "Congo" : "Kongó",
+    "Switzerland" : "Sviss",
+    "Côte d'Ivoire" : "Fílabeinsströndin",
+    "Cook Islands" : "Cook-eyjar",
+    "Chile" : "Síle",
+    "Cameroon" : "Kamerún",
+    "China" : "Kína",
+    "Colombia" : "Kólumbía",
+    "Costa Rica" : "Kosta Ríka",
+    "Cuba" : "Kúba",
+    "Cabo Verde" : "Grænhöfðaeyjar",
+    "Curaçao" : "Curaçao",
+    "Christmas Island" : "Jólaey",
+    "Cyprus" : "Kýpur",
+    "Czechia" : "Tékkland",
+    "Germany" : "Þýskaland",
+    "Djibouti" : "Djíbútí",
+    "Denmark" : "Danmörk",
+    "Dominica" : "Dóminíka",
+    "Dominican Republic" : "Dóminíkanska lýðveldið",
+    "Algeria" : "Alsír",
+    "Ecuador" : "Ekvador",
+    "Estonia" : "Eistland",
+    "Egypt" : "Egyptaland",
+    "Western Sahara" : "Vestur-Sahara",
+    "Eritrea" : "Erítrea",
+    "Spain" : "Spánn",
+    "Ethiopia" : "Eþíópía",
+    "Finland" : "Finnland",
+    "Fiji" : "Fídjieyjar",
+    "Falkland Islands (Malvinas)" : "Falklandseyjar",
+    "Faroe Islands" : "Færeyjar",
+    "France" : "Frakkland",
+    "Gabon" : "Gabon",
+    "United Kingdom of Great Britain and Northern Ireland" : "Samveldi Stóra-Bretlands og Norður-Írlands",
+    "Grenada" : "Grenada",
+    "Georgia" : "Georgía",
+    "French Guiana" : "Franska Gvæjana",
+    "Guernsey" : "Guernsey",
+    "Ghana" : "Gana",
+    "Gibraltar" : "Gíbraltar",
+    "Greenland" : "Grænland",
+    "Gambia" : "Gambía",
+    "Guinea" : "Gínea",
+    "Guadeloupe" : "Gvadelúpeyjar",
+    "Equatorial Guinea" : "Miðbaugs-Gínea",
+    "Greece" : "Grikkland",
+    "South Georgia and the South Sandwich Islands" : "Suður-Georgía og Suður-Sandwich eyjar",
+    "Guatemala" : "Gvatemala",
+    "Guam" : "Gvam",
+    "Guinea-Bissau" : "Gínea-Bissá",
+    "Guyana" : "Gvæjana",
+    "Hong Kong" : "Hong Kong",
+    "Heard Island and McDonald Islands" : "Heard-eyja og McDonald-eyjur",
+    "Honduras" : "Hondúras",
+    "Croatia" : "Króatía",
+    "Haiti" : "Haítí",
+    "Hungary" : "Ungverjaland",
+    "Indonesia" : "Indónesía",
+    "Ireland" : "Írland",
+    "Israel" : "Ísrael",
+    "Isle of Man" : "Mön",
+    "India" : "Indland",
+    "British Indian Ocean Territory" : "Bresku Indlandshafseyjar",
+    "Iraq" : "Írak",
+    "Iceland" : "Ísland",
+    "Italy" : "Ítalía",
+    "Jersey" : "Jersey",
+    "Jamaica" : "Jamaíka",
+    "Jordan" : "Jórdanía",
+    "Japan" : "Japan",
+    "Kenya" : "Kenía",
+    "Kyrgyzstan" : "Kirgisistan",
+    "Cambodia" : "Kambódía",
+    "Kiribati" : "Kíribatí",
+    "Comoros" : "Kómoreyjar",
+    "Saint Kitts and Nevis" : "Sankti Kitts og Neviseyjur",
+    "Korea, Republic of" : "Kórea, lýðveldið",
+    "Kuwait" : "Kúveit",
+    "Cayman Islands" : "Cayman-eyjar",
+    "Kazakhstan" : "Kasakstan",
+    "Lao People's Democratic Republic" : "Alþýðulýðveldið Laó",
+    "Lebanon" : "Líbanon",
+    "Saint Lucia" : "Sankti Lúsía",
+    "Liechtenstein" : "Liechtenstein",
+    "Sri Lanka" : "Srí Lanka",
+    "Liberia" : "Líbería",
+    "Lesotho" : "Lesótó",
+    "Lithuania" : "Litháen",
+    "Luxembourg" : "Lúxemborg",
+    "Latvia" : "Lettland",
+    "Libya" : "Líbía",
+    "Morocco" : "Marokkó",
+    "Monaco" : "Mónakó",
+    "Moldova, Republic of" : "Moldóvía, lýðveldið",
+    "Montenegro" : "Svartfjallaland",
+    "Saint Martin (French part)" : "Sankti Martin (franski hluti)",
+    "Madagascar" : "Madagaskar",
+    "Marshall Islands" : "Marshall eyjar",
+    "Mali" : "Malí",
+    "Myanmar" : "Mjanmar",
+    "Mongolia" : "Mongólía",
+    "Macao" : "Makaó",
+    "Northern Mariana Islands" : "Norður Maríanaeyjar",
+    "Martinique" : "Martiník",
+    "Mauritania" : "Máritanía",
+    "Montserrat" : "Montserrat",
+    "Malta" : "Malta",
+    "Mauritius" : "Máritus",
+    "Maldives" : "Maldíveyjar",
+    "Malawi" : "Malaví",
+    "Mexico" : "Mexíkó",
+    "Malaysia" : "Malasía",
+    "Mozambique" : "Mósambík",
+    "Namibia" : "Namibía",
+    "New Caledonia" : "Nýja-Kaledónía",
+    "Niger" : "Níger",
+    "Norfolk Island" : "Norfolkeyja",
+    "Nigeria" : "Nígería",
+    "Nicaragua" : "Nígarakúa",
+    "Netherlands" : "Holland",
+    "Norway" : "Noregur",
+    "Nepal" : "Nepal",
+    "Nauru" : "Nárú",
+    "Niue" : "Niue",
+    "New Zealand" : "Nýja-Sjáland",
+    "Oman" : "Óman",
+    "Panama" : "Panama",
+    "Peru" : "Perú",
+    "French Polynesia" : "Franska Pólýnesía",
+    "Papua New Guinea" : "Papúa Nýja-Gínea",
+    "Philippines" : "Filippseyjar",
+    "Pakistan" : "Pakistan",
+    "Poland" : "Pólland",
+    "Saint Pierre and Miquelon" : "Sankti Pierre og Miquelon",
+    "Pitcairn" : "Pitcairn",
+    "Puerto Rico" : "Puerto Ríko",
+    "Palestine, State of" : "Palestínuríki",
+    "Portugal" : "Portúgal",
+    "Palau" : "Palá",
+    "Paraguay" : "Paragvæ",
+    "Qatar" : "Katar",
+    "Réunion" : "Réunion",
+    "Romania" : "Rúmenía",
+    "Serbia" : "Serbía",
+    "Russian Federation" : "Rússneska sambandið",
+    "Rwanda" : "Rúanda",
+    "Saudi Arabia" : "Sádí-Arabía",
+    "Solomon Islands" : "Salómonseyjar",
+    "Seychelles" : "Seychelles-eyjar",
+    "Sudan" : "Súdan",
+    "Sweden" : "Svíþjóð",
+    "Singapore" : "Singapúr",
+    "Saint Helena, Ascension and Tristan da Cunha" : "Sankti Helena, Ascension og Tristan da Cunha",
+    "Slovenia" : "Slóvenía",
+    "Svalbard and Jan Mayen" : "Svalbarði og Jan Mayen",
+    "Slovakia" : "Slóvakía",
+    "Sierra Leone" : "Síerra Leóne",
+    "San Marino" : "San Marínó",
+    "Senegal" : "Senegal",
+    "Somalia" : "Sómalía",
+    "Suriname" : "Súrínam",
+    "South Sudan" : "Suður-Súdan",
+    "Sao Tome and Principe" : "Saó Tóme og Prinsípe",
+    "El Salvador" : "El Salvador",
+    "Sint Maarten (Dutch part)" : "Sankti Maarten (hollenski hluti)",
+    "Syrian Arab Republic" : "Sýrlenska arabalýðveldið",
+    "Eswatini" : "Eswatini",
+    "Turks and Caicos Islands" : "Turks og Kaikós eyjar",
+    "Chad" : "Tsjad",
+    "French Southern Territories" : "Frönsku suðurhafshéruðin",
+    "Togo" : "Tógó",
+    "Thailand" : "Tæland",
+    "Tajikistan" : "Tadsjikistan",
+    "Tokelau" : "Tókelá",
+    "Timor-Leste" : "Tímor-Leste",
+    "Turkmenistan" : "Túrkmenistan",
+    "Tunisia" : "Túnis",
+    "Tonga" : "Tonga",
+    "Turkey" : "Tyrkland",
+    "Trinidad and Tobago" : "Trínidad og Tóbagó",
+    "Tuvalu" : "Túvalú",
+    "Taiwan, Province of China" : "Tævan, hérað í Kína",
+    "Tanzania, United Republic of" : "Tansanía, sameinaða lýðveldið",
+    "Ukraine" : "Úkraína",
+    "Uganda" : "Úganda",
+    "United States Minor Outlying Islands" : "Ytri-smáeyjar Bandaríkjanna",
+    "United States of America" : "Bandaríki Norður-Ameríku",
+    "Uruguay" : "Úrúgvæ",
+    "Uzbekistan" : "Úsbekistan",
+    "Holy See" : "Vatíkanska borgríkið (Holy See)",
+    "Saint Vincent and the Grenadines" : "Sankti Vincent og Grenadín",
+    "Viet Nam" : "Víetnam",
+    "Vanuatu" : "Vanuatú",
+    "Wallis and Futuna" : "Wallis- og Fútúnaeyjar",
+    "Samoa" : "Samóa",
+    "Yemen" : "Jemen",
+    "Mayotte" : "Mayotte",
+    "South Africa" : "Suður-Afríka",
+    "Zambia" : "Sambía",
+    "Zimbabwe" : "Simbabve",
     "Invalid date, date format must be YYYY-MM-DD" : "Ógild dagsetning, dagsetningasniðið verður að vera ÁÁÁÁ-MM-DD",
     "Conversation not found" : "Samtal fannst ekki",
     "Path is already shared with this room" : "Slóðinni er þegar deilt með þessu spjallsvæði",
@@ -126,6 +367,15 @@ OC.L10N.register(
     "General settings" : "Almennar stillingar",
     "All messages" : "Öll skilaboð",
     "Off" : "Slökkt",
+    "Language" : "Tungumál",
+    "Country" : "Country",
+    "Status" : "Staða",
+    "Created at" : "Búið til",
+    "Pending" : "Í bið",
+    "Error" : "Villa",
+    "Blocked" : "Útilokaður",
+    "Active" : "Virkt",
+    "Expired" : "Útrunnið",
     "Signaling server URL" : "Slóð á merkjasendingaþjón",
     "Validate SSL certificate" : "Sannreyna SSL-skilríki",
     "Delete this server" : "Eyða þessum þjóni",
@@ -155,6 +405,7 @@ OC.L10N.register(
     "Share a single window" : "Deila stökum glugga",
     "Show your screen" : "Birta skjáinn þinn",
     "Stop screensharing" : "Hætta skjádeilingu",
+    "Dismiss" : "Hafna",
     "No audio" : "Ekkert hljóð",
     "Mute audio (m)" : "Þagga hljóð (m)",
     "Unmute audio (m)" : "Afþagga hljóð (m)",
@@ -184,7 +435,6 @@ OC.L10N.register(
     "Groups" : "Hópar",
     "Circles" : "Hringir",
     "Invalid path selected" : "Ógild slóð valin",
-    "Error" : "Villa",
     "Password protect" : "Verja með lykilorði",
     "Back" : "Til baka",
     "Close" : "Loka",
@@ -209,7 +459,6 @@ OC.L10N.register(
     "Settings" : "Stillingar",
     "Edit" : "Breyta",
     "Start call" : "Hefja samtal",
-    "Dismiss" : "Hafna",
     "Go to file" : "Fara í skrá",
     "Rename conversation" : "Endurnefna samtal",
     "Share link" : "Deila tengli",
