@@ -23,6 +23,25 @@ OC.L10N.register(
     "Join call" : "통화 참가하기",
     "{user} wants to talk with you" : "{user} 님이 여러분과 통화하려고 함",
     "A group call has started in {call}" : "그룹 통화가 {call}에 시작됨",
+    "Open settings" : "설정 열기",
+    "Andorra" : "안도라",
+    "Afghanistan" : "아프가니스탄",
+    "Anguilla" : "앵귈라",
+    "Albania" : "알바니아",
+    "Angola" : "앙골라",
+    "Antarctica" : "남극",
+    "Argentina" : "아르헨티나",
+    "American Samoa" : "미국령 사모아",
+    "Austria" : "오스트리아",
+    "Australia" : "오스트레일리아",
+    "Åland Islands" : "올란드 제도",
+    "Brazil" : "브라질",
+    "Bhutan" : "부탄",
+    "Canada" : "캐나다",
+    "China" : "중국",
+    "Algeria" : "알제리",
+    "Japan" : "일본",
+    "Singapore" : "싱가포르",
     "Invalid date, date format must be YYYY-MM-DD" : "잘못된 날짜, YYYY-MM-DD 형식이어야 합니다",
     "Leave call" : "통화 떠나기",
     "Limit to groups" : "그룹으로 제한",
@@ -40,6 +59,14 @@ OC.L10N.register(
     "Name" : "이름",
     "General settings" : "일반 설정",
     "Off" : "꺼짐",
+    "Language" : "언어",
+    "Country" : "Country",
+    "Status" : "상태",
+    "Created at" : "만든 날짜:",
+    "Pending" : "대기 중",
+    "Error" : "오류",
+    "Blocked" : "차단됨",
+    "Expired" : "만료됨",
     "Validate SSL certificate" : "SSL 인증서 확인",
     "Saved" : "저장됨",
     "Shared secret" : "공유된 비밀 값",
@@ -55,6 +82,7 @@ OC.L10N.register(
     "Share this link to invite others!" : "다른 사람을 초대하려면 링크를 공유하십시오!",
     "Show your screen" : "내 화면 보이기",
     "Stop screensharing" : "화면 공유 중지",
+    "Dismiss" : "무시",
     "Mute audio" : "오디오 음소거",
     "Disable video" : "비디오 비활성화",
     "Enable video" : "비디오 활성화",
@@ -78,7 +106,6 @@ OC.L10N.register(
     "Loading" : "불러오는 중",
     "Groups" : "그룹",
     "Circles" : "서클",
-    "Error" : "오류",
     "Password protect" : "암호 보호",
     "Back" : "뒤로",
     "Close" : "닫기",
@@ -100,7 +127,6 @@ OC.L10N.register(
     "Chat" : "대화",
     "Settings" : "설정",
     "Edit" : "편집",
-    "Dismiss" : "무시",
     "Rename conversation" : "대화 제목 변경",
     "Share link" : "링크 공유",
     "Password protection" : "암호 보호",
