@@ -131,6 +131,183 @@ OC.L10N.register(
     "{email} tried to request the password to access {file}" : "{email} bandė paprašyti slaptažodžio, kad gautų prieigą prie {file}",
     "Someone is requesting the password to access {file}" : "Kažkas prašo slaptažodžio, kad gautų prieigą prie {file}",
     "Someone tried to request the password to access {file}" : "Kažkas bandė paprašyti slaptažodžio, kad gautų prieigą prie {file}",
+    "Open settings" : "Atverti nustatymus",
+    "Andorra" : "Andora",
+    "United Arab Emirates" : "Jungtiniai Arabų Emyratai",
+    "Afghanistan" : "Afganistanas",
+    "Antigua and Barbuda" : "Antigva ir Barbuda",
+    "Anguilla" : "Angilija",
+    "Albania" : "Albanija",
+    "Armenia" : "Armėnija",
+    "Angola" : "Angola",
+    "Argentina" : "Argentina",
+    "Austria" : "Austrija",
+    "Australia" : "Australija",
+    "Azerbaijan" : "Azerbaidžanas",
+    "Bosnia and Herzegovina" : "Bosnija ir Hercegovina",
+    "Barbados" : "Barbadosas",
+    "Bangladesh" : "Bangladešas",
+    "Belgium" : "Belgija",
+    "Burkina Faso" : "Burkina Fasas",
+    "Bulgaria" : "Bulgarija",
+    "Bahrain" : "Bahreinas",
+    "Burundi" : "Burundis",
+    "Benin" : "Beninas",
+    "Bermuda" : "Bermudai",
+    "Brunei Darussalam" : "Brunėjaus Darusalamas",
+    "Brazil" : "Brazilija",
+    "Bahamas" : "Bahamos",
+    "Bhutan" : "Butanas",
+    "Botswana" : "Botsvana",
+    "Belarus" : "Baltarusija",
+    "Belize" : "Belizas",
+    "Canada" : "Kanada",
+    "Central African Republic" : "Centrinės Afrikos Respublika",
+    "Congo" : "Kongas",
+    "Switzerland" : "Šveicarija",
+    "Chile" : "Čilė",
+    "Cameroon" : "Kamerūnas",
+    "China" : "Kinija",
+    "Colombia" : "Kolumbija",
+    "Costa Rica" : "Kosta Rika",
+    "Cuba" : "Kuba",
+    "Cyprus" : "Kipras",
+    "Germany" : "Vokietija",
+    "Djibouti" : "Džibutis",
+    "Denmark" : "Danija",
+    "Dominica" : "Dominika",
+    "Dominican Republic" : "Dominikos Respublika",
+    "Algeria" : "Alžyras",
+    "Ecuador" : "Ekvadoras",
+    "Estonia" : "Estija",
+    "Egypt" : "Egiptas",
+    "Eritrea" : "Eritrėja",
+    "Spain" : "Ispanija",
+    "Ethiopia" : "Etiopija",
+    "Finland" : "Suomija",
+    "Fiji" : "Fidžis",
+    "France" : "Prancūzija",
+    "Gabon" : "Gabonas",
+    "Grenada" : "Grenada",
+    "Georgia" : "Gruzija",
+    "Ghana" : "Gana",
+    "Greenland" : "Grenlandija",
+    "Gambia" : "Gambija",
+    "Guinea" : "Gvinėja",
+    "Equatorial Guinea" : "Pusiaujo Gvinėja",
+    "Greece" : "Graikija",
+    "Guatemala" : "Gvatemala",
+    "Guinea-Bissau" : "Bisau Gvinėja",
+    "Guyana" : "Gajana",
+    "Honduras" : "Hondūras",
+    "Croatia" : "Kroatija",
+    "Haiti" : "Haitis",
+    "Hungary" : "Vengrija",
+    "Indonesia" : "Indonezija",
+    "Ireland" : "Airija",
+    "Israel" : "Izraelis",
+    "India" : "Indija",
+    "Iraq" : "Irakas",
+    "Iceland" : "Islandija",
+    "Italy" : "Italija",
+    "Jamaica" : "Jamaika",
+    "Jordan" : "Jordanija",
+    "Japan" : "Japonija",
+    "Kenya" : "Kenija",
+    "Kyrgyzstan" : "Kirgizija",
+    "Cambodia" : "Kambodža",
+    "Kiribati" : "Kiribatis",
+    "Saint Kitts and Nevis" : "Sent Kitsas ir Nevis",
+    "Kuwait" : "Kuveitas",
+    "Kazakhstan" : "Kazachstanas",
+    "Lebanon" : "Libanas",
+    "Liechtenstein" : "Lichtenšteinas",
+    "Sri Lanka" : "Šri Lanka",
+    "Liberia" : "Liberija",
+    "Lesotho" : "Lesotas",
+    "Lithuania" : "Lietuva",
+    "Luxembourg" : "Liuksemburgas",
+    "Latvia" : "Latvija",
+    "Libya" : "Libija",
+    "Morocco" : "Marokas",
+    "Monaco" : "Monakas",
+    "Montenegro" : "Juodkalnija",
+    "Madagascar" : "Madagaskaras",
+    "Mali" : "Malis",
+    "Myanmar" : "Mianmaras",
+    "Mongolia" : "Mongolija",
+    "Mauritania" : "Mauritanija",
+    "Malta" : "Malta",
+    "Mauritius" : "Mauricijus",
+    "Maldives" : "Maldyvai",
+    "Malawi" : "Malavis",
+    "Mexico" : "Meksika",
+    "Malaysia" : "Malaizija",
+    "Mozambique" : "Mozambikas",
+    "Namibia" : "Namibija",
+    "New Caledonia" : "Naujoji Kaledonija",
+    "Niger" : "Nigeris",
+    "Nigeria" : "Nigerija",
+    "Nicaragua" : "Nikaragva",
+    "Netherlands" : "Nyderlandai",
+    "Norway" : "Norvegija",
+    "Nepal" : "Nepalas",
+    "Nauru" : "Nauru",
+    "New Zealand" : "Naujoji Zelandija",
+    "Oman" : "Omanas",
+    "Panama" : "Panama",
+    "Peru" : "Peru",
+    "Papua New Guinea" : "Papua Naujoji Gvinėja",
+    "Philippines" : "Filipinai",
+    "Pakistan" : "Pakistanas",
+    "Poland" : "Lenkija",
+    "Pitcairn" : "Pitkerno salos",
+    "Puerto Rico" : "Puerto Rikas",
+    "Portugal" : "Portugalija",
+    "Paraguay" : "Paragvajus",
+    "Qatar" : "Kataras",
+    "Romania" : "Rumunija",
+    "Serbia" : "Serbija",
+    "Russian Federation" : "Rusijos Federacija",
+    "Rwanda" : "Ruanda",
+    "Saudi Arabia" : "Saudo Arabija",
+    "Solomon Islands" : "Saliamono salos",
+    "Seychelles" : "Seišelių salos",
+    "Sudan" : "Sudanas",
+    "Sweden" : "Švedija",
+    "Singapore" : "Singapūras",
+    "Slovenia" : "Slovėnija",
+    "Slovakia" : "Slovakija",
+    "Sierra Leone" : "Siera Leonė",
+    "Senegal" : "Senegalas",
+    "Somalia" : "Somalis",
+    "Suriname" : "Surinamas",
+    "South Sudan" : "Pietų Sudanas",
+    "El Salvador" : "Salvadoras",
+    "Syrian Arab Republic" : "Sirijos Arabų Respublika",
+    "Turks and Caicos Islands" : "Terkso ir Kaikoso salos",
+    "Chad" : "Čadas",
+    "Togo" : "Togas",
+    "Thailand" : "Tailandas",
+    "Tajikistan" : "Tadžikistanas",
+    "Timor-Leste" : "Rytų Timoras",
+    "Turkmenistan" : "Turkmėnistanas",
+    "Tunisia" : "Tunisas",
+    "Tonga" : "Tongų",
+    "Turkey" : "Turkija",
+    "Trinidad and Tobago" : "Trinidadas ir Tobagas",
+    "Tanzania, United Republic of" : "Tanzanijos Jungtinė Respublika",
+    "Ukraine" : "Ukraina",
+    "Uganda" : "Uganda",
+    "United States Minor Outlying Islands" : "Jungtinių Valstijų nuošalios mažosios salos",
+    "United States of America" : "Jungtinės Amerikos Valstijos",
+    "Uruguay" : "Urugvajus",
+    "Uzbekistan" : "Uzbekistanas",
+    "Vanuatu" : "Vanuatu",
+    "Yemen" : "Jemenas",
+    "South Africa" : "Pietų Afrika",
+    "Zambia" : "Zambija",
+    "Zimbabwe" : "Zimbabvė",
     "Invalid date, date format must be YYYY-MM-DD" : "Netinkama data, datos formatas privalo būti MMMM-mm-dd",
     "Conversation not found" : "Pokalbis nerastas",
     "Path is already shared with this room" : "Kelias jau yra bendrinamas su šiuo kambariu",
@@ -167,6 +344,18 @@ OC.L10N.register(
     "All messages" : "Visos žinutės",
     "@-mentions only" : "Tik @ paminėjimai",
     "Off" : "Išjungta",
+    "E-mail of the user" : "Naudotojo el. paštas",
+    "Language" : "Kalba",
+    "Country" : "Šalis",
+    "Status" : "Būsena",
+    "Created at" : "Sukurta",
+    "Pending" : "Laukiantis",
+    "Error" : "Klaida",
+    "Blocked" : "Blokuota",
+    "Active" : "Aktyvi",
+    "Expired" : "Nebegalioja",
+    "The account could not be deleted. Please try again later." : "Nepavyko ištrinti paskyros. Vėliau bandykite dar kartą.",
+    "_%n user_::_%n users_" : ["%n naudotojas","%n naudotojai","%n naudotojų","%n naudotojas"],
     "Signaling server URL" : "Signalinio serverio URL",
     "Delete this server" : "Ištrinti šį serverį",
     "Status: Checking connection" : "Būsena: Tikrinamas ryšys",
@@ -199,6 +388,7 @@ OC.L10N.register(
     "Share a single window" : "Bendrinti vieną langą",
     "Show your screen" : "Rodyti savo ekraną",
     "Stop screensharing" : "Stabdyti ekrano bendrinimą",
+    "Dismiss" : "Atmesti",
     "No audio" : "Nėra jokio garso",
     "Mute audio (m)" : "Nutildyti garsą (m)",
     "Unmute audio (m)" : "Įjungti garsą (m)",
@@ -251,7 +441,6 @@ OC.L10N.register(
     "Copy conversation link" : "Kopijuoti pokalbio nuorodą",
     "Error while creating the conversation" : "Klaida kuriant pokalbį",
     "Link copied to the clipboard!" : "Nuoroda nukopijuota į iškarpinę!",
-    "Error" : "Klaida",
     "Create a new group conversation" : "Sukurti naują grupės pokalbį",
     "Password protect" : "Apsaugoti slaptažodžiu",
     "Add participants" : "Pridėti dalyvius",
@@ -296,7 +485,6 @@ OC.L10N.register(
     "Display name: " : "Rodomas vardas: ",
     "Edit" : "Taisyti",
     "Start call" : "Pradėti skambutį",
-    "Dismiss" : "Atmesti",
     "Toggle fullscreen" : "Perjungti visą ekraną",
     "Go to file" : "Pereiti į failą",
     "Rename conversation" : "Pervadinti pokalbį",
