@@ -94,6 +94,240 @@ OC.L10N.register(
     "You missed a call from {user}" : "Имате пропуштен повик од {user}",
     "You missed a group call in {call}" : "Имате пропуштен групен повик во {call}",
     "{email} is requesting the password to access {file}" : "{email} побара лозинка за пристап до {file}",
+    "Andorra" : "Андора",
+    "United Arab Emirates" : "Обединети Арапски Емирати",
+    "Afghanistan" : "Афганистан",
+    "Antigua and Barbuda" : "Антигва и Барбуда",
+    "Anguilla" : "Ангила",
+    "Albania" : "Албанија",
+    "Armenia" : "Ерменија",
+    "Angola" : "Ангола",
+    "Antarctica" : "Антарктик",
+    "Argentina" : "Аргентина",
+    "American Samoa" : "Американска Самоа",
+    "Austria" : "Австрија",
+    "Australia" : "Австралија",
+    "Aruba" : "Аруба",
+    "Åland Islands" : "Оландски острови",
+    "Azerbaijan" : "Азербејџан",
+    "Bosnia and Herzegovina" : "Босна и Херцеговина",
+    "Barbados" : "Барбадос",
+    "Bangladesh" : "Бангладеш",
+    "Belgium" : "Белгија",
+    "Burkina Faso" : "Буркина Фасо",
+    "Bulgaria" : "Бугарија",
+    "Bahrain" : "Бахреин",
+    "Burundi" : "Бурунди",
+    "Benin" : "Бенин",
+    "Saint Barthélemy" : "Свети Вартоломеј",
+    "Bermuda" : "Бермуда",
+    "Brunei Darussalam" : "Брунеј",
+    "Bonaire, Sint Eustatius and Saba" : "Бонер, Свети Евстахиј и Саба",
+    "Brazil" : "Бразил",
+    "Bahamas" : "Бахами",
+    "Bhutan" : "Бутан",
+    "Bouvet Island" : "Остров Буве",
+    "Botswana" : "Боцвана",
+    "Belarus" : "Белорусија",
+    "Belize" : "Белизе",
+    "Canada" : "Канада",
+    "Cocos (Keeling) Islands" : "Кокосови Острови",
+    "Central African Republic" : "Централна Африканска Република",
+    "Congo" : "Конго",
+    "Switzerland" : "Швајцарија",
+    "Côte d'Ivoire" : "Брегот на Слоновата Коска",
+    "Cook Islands" : "Кукови Острови",
+    "Chile" : "Чиле",
+    "Cameroon" : "Камерун",
+    "China" : "Кина",
+    "Colombia" : "Колумбија",
+    "Costa Rica" : "Костарика",
+    "Cuba" : "Куба",
+    "Cabo Verde" : "Зелен ’Рт",
+    "Curaçao" : "Курасао",
+    "Christmas Island" : "Божиќен Остров",
+    "Cyprus" : "Кипар",
+    "Czechia" : "Чешка",
+    "Germany" : "Германија",
+    "Djibouti" : "Џибути",
+    "Denmark" : "Данска",
+    "Dominica" : "Доминика",
+    "Dominican Republic" : "Доминиканска Република",
+    "Algeria" : "Алжир",
+    "Ecuador" : "Еквадор",
+    "Estonia" : "Естонија",
+    "Egypt" : "Египет",
+    "Western Sahara" : "Западна Сахара",
+    "Eritrea" : "Еритреја",
+    "Spain" : "Шпанија",
+    "Ethiopia" : "Етиопија",
+    "Finland" : "Финска",
+    "Fiji" : "Фиџи",
+    "Falkland Islands (Malvinas)" : "Фолкландски Острови",
+    "Faroe Islands" : "Фарски Острови",
+    "France" : "Франција",
+    "Gabon" : "Габон",
+    "United Kingdom of Great Britain and Northern Ireland" : "Кралство на Велика Британија и Северна Ирска",
+    "Grenada" : "Гренада",
+    "Georgia" : "Грузија",
+    "French Guiana" : "Француска Гвајана",
+    "Guernsey" : "Гернзи",
+    "Ghana" : "Гана",
+    "Gibraltar" : "Гибралтар",
+    "Greenland" : "Гренланд",
+    "Gambia" : "Гамбија",
+    "Guinea" : "Гвинеја",
+    "Guadeloupe" : "Гваделуп",
+    "Equatorial Guinea" : "Екваторијална Гвинеја",
+    "Greece" : "Грција",
+    "South Georgia and the South Sandwich Islands" : "Јужна Џорџија и Јужни Сендвички Острови",
+    "Guatemala" : "Гватемала",
+    "Guam" : "Гуам",
+    "Guinea-Bissau" : "Гвинеја-Бисао",
+    "Guyana" : "Гвајана",
+    "Hong Kong" : "Хонгконг",
+    "Honduras" : "Хондурас",
+    "Croatia" : "Хрватска",
+    "Haiti" : "Хаити",
+    "Hungary" : "Унгарија",
+    "Indonesia" : "Индонезија",
+    "Ireland" : "Ирска",
+    "Israel" : "Израел",
+    "Isle of Man" : "Остров Ман",
+    "India" : "Индија",
+    "British Indian Ocean Territory" : "Британска Индоокеанска Територија",
+    "Iraq" : "Ирак",
+    "Iceland" : "Исланд",
+    "Italy" : "Италија",
+    "Jersey" : "Џерси",
+    "Jamaica" : "Јамајка",
+    "Jordan" : "Јордан",
+    "Japan" : "Јапонија",
+    "Kenya" : "Кенија",
+    "Kyrgyzstan" : "Киргистан",
+    "Cambodia" : "Камбоџа",
+    "Kiribati" : "Кирибати",
+    "Comoros" : "Коморски Острови",
+    "Saint Kitts and Nevis" : "Свети Кристофер и Невис",
+    "Kuwait" : "Кувајт",
+    "Cayman Islands" : "Кајмански Острови",
+    "Kazakhstan" : "Казахстан",
+    "Lao People's Democratic Republic" : "Лаошка Народна Демократска Република",
+    "Lebanon" : "Либан",
+    "Saint Lucia" : "Света Луција",
+    "Liechtenstein" : "Лихтенштајн",
+    "Sri Lanka" : "Шри Ланка",
+    "Liberia" : "Либерија",
+    "Lesotho" : "Лесото",
+    "Lithuania" : "Литванија",
+    "Luxembourg" : "Луксембург",
+    "Latvia" : "Летонија",
+    "Libya" : "Либија",
+    "Morocco" : "Мароко",
+    "Monaco" : "Монако",
+    "Montenegro" : "Црна Гора",
+    "Saint Martin (French part)" : "Свети Мартин (остров)",
+    "Madagascar" : "Мадагаскар",
+    "Marshall Islands" : "Маршалски Острови",
+    "Mali" : "Мали",
+    "Myanmar" : "Мјанмар",
+    "Mongolia" : "Монголија",
+    "Macao" : "Макао",
+    "Northern Mariana Islands" : "Северни Маријански Острови",
+    "Martinique" : "Мартиник",
+    "Mauritania" : "Мавританија",
+    "Montserrat" : "Монтсерат",
+    "Malta" : "Малта",
+    "Mauritius" : "Маврициус",
+    "Maldives" : "Малдиви",
+    "Malawi" : "Малави",
+    "Mexico" : "Мексико",
+    "Malaysia" : "Малезија",
+    "Mozambique" : "Мозамбик",
+    "Namibia" : "Намибија",
+    "New Caledonia" : "Нова Каледонија",
+    "Niger" : "Нигер",
+    "Norfolk Island" : "Норфолшки Остров",
+    "Nigeria" : "Нигерија",
+    "Nicaragua" : "Никарагва",
+    "Netherlands" : "Холандија",
+    "Norway" : "Норвешка",
+    "Nepal" : "Непал",
+    "Nauru" : "Република Науру",
+    "Niue" : "Ниуе",
+    "New Zealand" : "Нов Зеланд",
+    "Oman" : "Оман",
+    "Panama" : "Панама",
+    "Peru" : "Перу",
+    "French Polynesia" : "Француска Полинезија",
+    "Papua New Guinea" : "Папуа Нова Гвинеја",
+    "Philippines" : "Филипини",
+    "Pakistan" : "Пакистан",
+    "Poland" : "Полска",
+    "Saint Pierre and Miquelon" : "Свети Пјер и Микелон",
+    "Pitcairn" : "Питкерн",
+    "Puerto Rico" : "Порто Рико",
+    "Palestine, State of" : "Држава Палестина",
+    "Portugal" : "Португалија",
+    "Palau" : "Република Палау",
+    "Paraguay" : "Парагвај",
+    "Qatar" : "Катар",
+    "Réunion" : "Реинион",
+    "Romania" : "Романија",
+    "Serbia" : "Србија",
+    "Russian Federation" : "Руска Федерација",
+    "Rwanda" : "Руанда",
+    "Saudi Arabia" : "Саудиска Арабија",
+    "Solomon Islands" : "Соломонски острови",
+    "Seychelles" : "Сејшели",
+    "Sudan" : "Судан",
+    "Sweden" : "Шведска",
+    "Singapore" : "Сингапур",
+    "Saint Helena, Ascension and Tristan da Cunha" : "Света Елена, Вознесение и Тристан да Куња",
+    "Slovenia" : "Словенија",
+    "Slovakia" : "Словачка",
+    "Sierra Leone" : "Сиера Леоне",
+    "San Marino" : "Сан Марино",
+    "Senegal" : "Сенегал",
+    "Somalia" : "Сомалија",
+    "Suriname" : "Суринам",
+    "South Sudan" : "Јужен Судан",
+    "Sao Tome and Principe" : "Сао Томе и Принсипе",
+    "El Salvador" : "Ел Салвадор",
+    "Sint Maarten (Dutch part)" : "Свети Мартин (Холандија)",
+    "Syrian Arab Republic" : "Сириска Арапска Република",
+    "Turks and Caicos Islands" : "Туркс и Кајкос",
+    "Chad" : "Чад",
+    "French Southern Territories" : "Француски Јужни и Антарктички Земји",
+    "Togo" : "Того",
+    "Thailand" : "Тајланд",
+    "Tajikistan" : "Таџикистан",
+    "Tokelau" : "Токелау",
+    "Timor-Leste" : "Тимор-Лест",
+    "Turkmenistan" : "Туркменистан",
+    "Tunisia" : "Тунис",
+    "Tonga" : "Tonga",
+    "Turkey" : "Турција",
+    "Trinidad and Tobago" : "Тринидад и Тобаго",
+    "Tuvalu" : "Тувалу",
+    "Tanzania, United Republic of" : "Обединета Република Танзанија",
+    "Ukraine" : "Украина",
+    "Uganda" : "Уганда",
+    "United States Minor Outlying Islands" : "Мали оддалечени острови на САД",
+    "United States of America" : "Соединетите Американски Држави",
+    "Uruguay" : "Уругвај",
+    "Uzbekistan" : "Узбекистан",
+    "Holy See" : "Света столица",
+    "Saint Vincent and the Grenadines" : "Свети Винцент и Гренадини",
+    "Viet Nam" : "Социјалистичка Република Виетнам",
+    "Vanuatu" : "Вануату",
+    "Wallis and Futuna" : "Валис и Футуна",
+    "Samoa" : "Самоа",
+    "Yemen" : "Јемен",
+    "Mayotte" : "Мајот",
+    "South Africa" : "Јужна Африка",
+    "Zambia" : "Замбија",
+    "Zimbabwe" : "Зимбабве",
     "Invalid date, date format must be YYYY-MM-DD" : "Невалиден датум, форматот мора да биде ГГГГ-ММ-ДД",
     "Conversation not found" : "Разговорот не е пронајден",
     "Leave call" : "Напушти го повикот",
@@ -128,6 +362,12 @@ OC.L10N.register(
     "All messages" : "Сите пораки",
     "@-mentions only" : "само @-спомнување ",
     "Off" : "Исклучени",
+    "Language" : "Јазик",
+    "Country" : "Држава",
+    "Status" : "Статус",
+    "Pending" : "Чекање",
+    "Error" : "Грешка",
+    "Active" : "Активно",
     "Signaling server URL" : "URL за сервер за сигнализација",
     "Saved" : "Зачувано",
     "Copy link" : "Копирај линк",
@@ -141,6 +381,7 @@ OC.L10N.register(
     "Share a single window" : "Сподели единечен прозор",
     "Show your screen" : "Прикажи го вашиот екран",
     "Stop screensharing" : "Запри споделување на екран",
+    "Dismiss" : "Отфрли",
     "No audio" : "Нема аудио",
     "Mute audio (m)" : "Занеми (Mute) го аудиото (m)",
     "Unmute audio (m)" : "Одзанеми (Unmute) го аудиото (m)",
@@ -183,7 +424,6 @@ OC.L10N.register(
     "Error while setting attachment folder" : "Грешка при поставување на папка за прилози",
     "Copy conversation link" : "копирај линк од разговорот",
     "Link copied to the clipboard!" : "Линкот е копиран во клипборд!",
-    "Error" : "Грешка",
     "Create a new group conversation" : "Креирајте нов групен разговор",
     "Password protect" : "Заштити со лозинка",
     "Add participants" : "Додади учесници",
@@ -224,7 +464,6 @@ OC.L10N.register(
     "Display name: " : "Име:",
     "Edit" : "Уреди",
     "Start call" : "Повик",
-    "Dismiss" : "Отфрли",
     "Go to file" : "Оди до датотеката",
     "Rename conversation" : "Преименувај разговор",
     "Share link" : "Сподели линк",
