@@ -16,6 +16,64 @@ OC.L10N.register(
     "Join call" : "Ta del i samtale",
     "{user} wants to talk with you" : "{user} ønsker å snakke med deg",
     "A group call has started in {call}" : "En gruppesamtale har startet i {call}",
+    "Open settings" : "Åpne innstillinger",
+    "Andorra" : "Andorra",
+    "United Arab Emirates" : "De forente arabiske emirater",
+    "Afghanistan" : "Afganistan",
+    "Anguilla" : "Angola",
+    "Albania" : "Albania",
+    "Armenia" : "Armenia",
+    "Angola" : "Angola",
+    "Argentina" : "Argentina",
+    "Austria" : "Østerike",
+    "Australia" : "Australia",
+    "Aruba" : "Aruba",
+    "Åland Islands" : "Åland",
+    "Bosnia and Herzegovina" : "Bosnia og Hersegovina",
+    "Barbados" : "Barbados",
+    "Bangladesh" : "Bangladesh",
+    "Belgium" : "Belgia",
+    "Bulgaria" : "Bulgaria",
+    "Burundi" : "Burundi",
+    "Bermuda" : "Bermuda",
+    "Brazil" : "Brasil",
+    "Bahamas" : "Bahamas",
+    "Botswana" : "Botswana",
+    "Belarus" : "Hviterusland",
+    "Canada" : "Kanada",
+    "Congo" : "Kongo",
+    "Switzerland" : "Sveits",
+    "Chile" : "Chile",
+    "Cameroon" : "Kameron",
+    "China" : "Kina",
+    "Colombia" : "Kolombia",
+    "Costa Rica" : "Costa Rica",
+    "Cuba" : "Kuba",
+    "Cyprus" : "Kypros",
+    "Denmark" : "Danmark",
+    "Algeria" : "Algeri",
+    "Spain" : "Spania",
+    "Croatia" : "Kroatia",
+    "Iraq" : "Irak",
+    "Iceland" : "Island",
+    "Italy" : "Italia",
+    "Cambodia" : "Kambodia",
+    "Sri Lanka" : "Sri Lanka",
+    "Norway" : "Norge",
+    "Serbia" : "Serbia",
+    "Sudan" : "Sudan",
+    "Sweden" : "Sverige",
+    "Singapore" : "Singapore",
+    "Slovenia" : "Slovenia",
+    "Svalbard and Jan Mayen" : "Svalbard og Jan Mayen",
+    "Slovakia" : "Slovakia",
+    "Sierra Leone" : "Sierra Leone",
+    "Senegal" : "Senegal",
+    "Somalia" : "Somalia",
+    "Thailand" : "Thailand",
+    "Tonga" : "Tonga",
+    "Trinidad and Tobago" : "Trinidad og Tobago",
+    "Uganda" : "Uganda",
     "Invalid date, date format must be YYYY-MM-DD" : "Feil dato, dato må være i formatet YYYY-MM-DD",
     "Leave call" : "Forlat samtalen",
     "Limit to groups" : "Begrens til grupper",
@@ -30,6 +88,14 @@ OC.L10N.register(
     "Name" : "Navn",
     "General settings" : "Generelle innstillinger",
     "Off" : "ett kvarter",
+    "Language" : "Språk",
+    "Country" : "Land",
+    "Status" : "Status",
+    "Created at" : "Opprettet den",
+    "Pending" : "Venter",
+    "Error" : "Feil",
+    "Blocked" : "Blokkert",
+    "Expired" : "Utløpt",
     "Signaling server URL" : "Sender signal til servers URL",
     "Validate SSL certificate" : "Bekreft SSL-sertifikat",
     "Saved" : "Lagret",
@@ -48,6 +114,7 @@ OC.L10N.register(
     "Share this link to invite others!" : "Klikk denne lenken for å invitere andre.",
     "Show your screen" : "Vis din skjerm",
     "Stop screensharing" : "Stopp skjermdeling",
+    "Dismiss" : "Forkast",
     "No audio" : "Ingen lyd",
     "Mute audio (m)" : "Slå av lyd (m)",
     "Unmute audio (m)" : "Slå på lyd (m)",
@@ -74,7 +141,6 @@ OC.L10N.register(
     "Loading" : "Laster",
     "Groups" : "Grupper",
     "Circles" : "Sirkler",
-    "Error" : "Feil",
     "Password protect" : "Passordbeskyttelse",
     "Back" : "Tilbake",
     "Close" : "Lukk",
@@ -97,7 +163,6 @@ OC.L10N.register(
     "Settings" : "Innstillinger",
     "Edit" : "Rediger",
     "Start call" : "Start samtale",
-    "Dismiss" : "Forkast",
     "Rename conversation" : "Endre navn på samtale",
     "Share link" : "Del lenke",
     "Password protection" : "Passordbeskyttelse",
