@@ -21,6 +21,39 @@ OC.L10N.register(
     "Join call" : "Juntar-se à chamada",
     "{user} wants to talk with you" : "{user} quer falar consigo",
     "A group call has started in {call}" : "Uma chamada de grupo começou em {call}",
+    "Open settings" : "Abrir definições",
+    "Andorra" : "Andorra",
+    "Afghanistan" : "Afeganistão",
+    "Armenia" : "Arménia",
+    "Angola" : "Angola",
+    "Argentina" : "Argentina",
+    "Austria" : "Áustria",
+    "Australia" : "Austrália",
+    "Azerbaijan" : "Azerbaijão",
+    "Bangladesh" : "Bangladesh",
+    "Belgium" : "Bélgica",
+    "Burkina Faso" : "Burkina Faso",
+    "Bulgaria" : "Bulgária",
+    "Brazil" : "Brasil",
+    "Bahamas" : "Bahamas",
+    "Botswana" : "Botswana",
+    "Canada" : "Canada",
+    "Congo" : "Congo",
+    "Chile" : "Chile",
+    "Cameroon" : "Camarões",
+    "China" : "China",
+    "Colombia" : "Colômbia",
+    "Costa Rica" : "Costa Rica",
+    "Cuba" : "Cuba",
+    "Cabo Verde" : "Cabo Verde",
+    "Denmark" : "Dinamarca",
+    "Algeria" : "Algéria",
+    "Estonia" : "Estónia",
+    "Ethiopia" : "Etiópia",
+    "Finland" : "Finlândia",
+    "France" : "França",
+    "Croatia" : "Croácia",
+    "Portugal" : "Portugal",
     "Invalid date, date format must be YYYY-MM-DD" : "Data inválida, o formato da data deve ser AAAA-MM-DD",
     "Leave call" : "Sair da chamada",
     "Limit to groups" : "Limitado a grupos",
@@ -32,6 +65,14 @@ OC.L10N.register(
     "Disabled" : "Desactivado",
     "Users" : "Utilizadores",
     "Name" : "Nome",
+    "Language" : "Idioma",
+    "Country" : "País",
+    "Status" : "Estado",
+    "Created at" : "Criado em",
+    "Pending" : "Pendente",
+    "Error" : "Erro",
+    "Blocked" : "Bloqueado",
+    "Expired" : "Expirado",
     "Validate SSL certificate" : "Validar certificado SSL",
     "Saved" : "Gravado",
     "Shared secret" : "Segredo partilhado",
@@ -43,6 +84,7 @@ OC.L10N.register(
     "Waiting for others to join the call …" : "À espera que outros se juntem à chamada ..",
     "You can invite others in the participant tab of the sidebar" : "Pode convidar outros no separador participantes na barra lateral  ",
     "Share this link to invite others!" : "Envie este link para convidar outros!",
+    "Dismiss" : "Dispensar",
     "Mute audio" : "Silenciar áudio",
     "Disable video" : "desactivar vídeo",
     "Enable video" : "activar vídeo",
@@ -64,7 +106,6 @@ OC.L10N.register(
     "Loading" : "A carregar",
     "Groups" : "Grupos",
     "Circles" : "Círculos",
-    "Error" : "Erro",
     "Password protect" : "Proteger com palavra-passe",
     "Back" : "Anterior",
     "Close" : "Fechar",
@@ -85,7 +126,6 @@ OC.L10N.register(
     "Chat" : "Conversa",
     "Settings" : "Definições",
     "Edit" : "Editar",
-    "Dismiss" : "Dispensar",
     "Rename conversation" : "Renomear conversação",
     "Share link" : "Partilhar hiperligação",
     "Password protection" : "Protegido por palavra-passe",
