@@ -126,6 +126,243 @@ OC.L10N.register(
     "{email} tried to request the password to access {file}" : "{email} försökte begära lösenordet för åtkomst till {file}",
     "Someone is requesting the password to access {file}" : "Någon begär lösenordet för att komma åt {file}",
     "Someone tried to request the password to access {file}" : "Någon försökte begära lösenordet för att komma åt {file}",
+    "Open settings" : "Öppna inställningar",
+    "Andorra" : "Andorra",
+    "United Arab Emirates" : "Förenade arabemiraten",
+    "Afghanistan" : "Afghanistan",
+    "Antigua and Barbuda" : "Antigua och Barbuda",
+    "Anguilla" : "Anguilla",
+    "Albania" : "Albanien",
+    "Armenia" : "Armenien",
+    "Angola" : "Angola",
+    "Antarctica" : "Antarktis",
+    "Argentina" : "Argentina",
+    "American Samoa" : "Amerikanska Samoa",
+    "Austria" : "Österrike",
+    "Australia" : "Australien",
+    "Aruba" : "Aruba",
+    "Åland Islands" : "Åland",
+    "Azerbaijan" : "Azerbajdzjan",
+    "Bosnia and Herzegovina" : "Bosnien och Herzegovina",
+    "Barbados" : "Barbados",
+    "Bangladesh" : "Bangladesh",
+    "Belgium" : "Belgien",
+    "Burkina Faso" : "Burkina Faso",
+    "Bulgaria" : "Bulgarien",
+    "Bahrain" : "Bahrain",
+    "Burundi" : "Burundi",
+    "Benin" : "Benin",
+    "Saint Barthélemy" : "Saint Barthélemy",
+    "Bermuda" : "Bermuda",
+    "Brunei Darussalam" : "Brunei Darussalam",
+    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius and Saba",
+    "Brazil" : "Brasilien",
+    "Bahamas" : "Bahamas",
+    "Bhutan" : "Bhutan",
+    "Bouvet Island" : "Bouvet Island",
+    "Botswana" : "Botswana",
+    "Belarus" : "Vitryssland",
+    "Belize" : "Belize",
+    "Canada" : "Kanada",
+    "Cocos (Keeling) Islands" : "Cocos (Keeling) Islands",
+    "Central African Republic" : "Centralafrikanska republiken",
+    "Congo" : "Kongo, Republiken (Brazzaville)",
+    "Switzerland" : "Schweiz",
+    "Côte d'Ivoire" : "Elfenbenskusten",
+    "Cook Islands" : "Cook Islands",
+    "Chile" : "Chile",
+    "Cameroon" : "Kamerun",
+    "China" : "Kina",
+    "Colombia" : "Colombia",
+    "Costa Rica" : "Costa Rica",
+    "Cuba" : "Kuba",
+    "Cabo Verde" : "Kap Verde",
+    "Curaçao" : "Curaçao",
+    "Christmas Island" : "Julön",
+    "Cyprus" : "Cypern",
+    "Czechia" : "Tjeckien",
+    "Germany" : "Tyskland",
+    "Djibouti" : "Djibouti",
+    "Denmark" : "Danmark",
+    "Dominica" : "Dominica",
+    "Dominican Republic" : "Dominikanska republiken",
+    "Algeria" : "Algeriet",
+    "Ecuador" : "Ecuador",
+    "Estonia" : "Estland",
+    "Egypt" : "Egypten",
+    "Western Sahara" : "Västsahara",
+    "Eritrea" : "Eritrea",
+    "Spain" : "Spanien",
+    "Ethiopia" : "Etiopien",
+    "Finland" : "Finland",
+    "Fiji" : "Fiji",
+    "Falkland Islands (Malvinas)" : "Falklandsöarna (Malvinas)",
+    "Faroe Islands" : "Färöarna",
+    "France" : "Frankrike",
+    "Gabon" : "Gabon",
+    "United Kingdom of Great Britain and Northern Ireland" : "Förenade konungariket Storbritannien och Nordirland",
+    "Grenada" : "Grenada",
+    "Georgia" : "Georgien",
+    "French Guiana" : "Franska Guyana",
+    "Guernsey" : "Guernsey",
+    "Ghana" : "Ghana",
+    "Gibraltar" : "Gibraltar",
+    "Greenland" : "Grönland",
+    "Gambia" : "Gambia",
+    "Guinea" : "Guinea",
+    "Guadeloupe" : "Guadeloupe",
+    "Equatorial Guinea" : "Equatorial Guinea",
+    "Greece" : "Grekland",
+    "South Georgia and the South Sandwich Islands" : "South Georgia and the South Sandwich Islands",
+    "Guatemala" : "Guatemala",
+    "Guam" : "Guam",
+    "Guinea-Bissau" : "Guinea-Bissau",
+    "Guyana" : "Guyana",
+    "Hong Kong" : "Hong Kong",
+    "Heard Island and McDonald Islands" : "Heard Island och McDonald Islands",
+    "Honduras" : "Honduras",
+    "Croatia" : "Kroatien",
+    "Haiti" : "Haiti",
+    "Hungary" : "Ungern",
+    "Indonesia" : "Indonesien",
+    "Ireland" : "Irland",
+    "Israel" : "Israel",
+    "Isle of Man" : "Isle of Man",
+    "India" : "Indien",
+    "British Indian Ocean Territory" : "British Indian Ocean Territory",
+    "Iraq" : "Irak",
+    "Iceland" : "Island",
+    "Italy" : "Italien",
+    "Jersey" : "Jersey",
+    "Jamaica" : "Jamaica",
+    "Jordan" : "Jordanien",
+    "Japan" : "Japan",
+    "Kenya" : "Kenya",
+    "Kyrgyzstan" : "Kirgizistan",
+    "Cambodia" : "Kambodja",
+    "Kiribati" : "Kiribati",
+    "Comoros" : "Comoros",
+    "Saint Kitts and Nevis" : "Saint Kitts and Nevis",
+    "Kuwait" : "Kuwait",
+    "Cayman Islands" : "Cayman Islands",
+    "Kazakhstan" : "Kazakstan",
+    "Lao People's Democratic Republic" : "Lao People's Democratic Republic",
+    "Lebanon" : "Libanon",
+    "Saint Lucia" : "Saint Lucia",
+    "Liechtenstein" : "Liechtenstein",
+    "Sri Lanka" : "Sri Lanka",
+    "Liberia" : "Liberia",
+    "Lesotho" : "Lesotho",
+    "Lithuania" : "Litauen",
+    "Luxembourg" : "Luxemburg",
+    "Latvia" : "Lettland",
+    "Libya" : "Libyen",
+    "Morocco" : "Marocko",
+    "Monaco" : "Monaco",
+    "Montenegro" : "Montenegro",
+    "Saint Martin (French part)" : "Saint Martin (French part)",
+    "Madagascar" : "Madagaskar",
+    "Marshall Islands" : "Marshall Islands",
+    "Mali" : "Mali",
+    "Myanmar" : "Myanmar",
+    "Mongolia" : "Mongoliet",
+    "Macao" : "Macao",
+    "Northern Mariana Islands" : "Northern Mariana Islands",
+    "Martinique" : "Martinique",
+    "Mauritania" : "Mauretanien",
+    "Montserrat" : "Montserrat",
+    "Malta" : "Malta",
+    "Mauritius" : "Mauritius",
+    "Maldives" : "Maldiverna",
+    "Malawi" : "Malawi",
+    "Mexico" : "Mexico",
+    "Malaysia" : "Malaysia",
+    "Mozambique" : "Mozambique",
+    "Namibia" : "Namibia",
+    "New Caledonia" : "Nya Kaledonien",
+    "Niger" : "Niger",
+    "Norfolk Island" : "Norfolk Island",
+    "Nigeria" : "Nigeria",
+    "Nicaragua" : "Nicaragua",
+    "Netherlands" : "Nederländerna",
+    "Norway" : "Norge",
+    "Nepal" : "Nepal",
+    "Nauru" : "Nauru",
+    "Niue" : "Niue",
+    "New Zealand" : "Nya Zeeland",
+    "Oman" : "Oman",
+    "Panama" : "Panama",
+    "Peru" : "Peru",
+    "French Polynesia" : "Franska Polynesien",
+    "Papua New Guinea" : "Papua Nya Guinea",
+    "Philippines" : "Filippinerna",
+    "Pakistan" : "Pakistan",
+    "Poland" : "Polen",
+    "Saint Pierre and Miquelon" : "Saint Pierre and Miquelon",
+    "Pitcairn" : "Pitcairn",
+    "Puerto Rico" : "Puerto Rico",
+    "Palestine, State of" : "Palestine, State of",
+    "Portugal" : "Portugal",
+    "Palau" : "Palau",
+    "Paraguay" : "Paraguay",
+    "Qatar" : "Qatar",
+    "Réunion" : "Réunion",
+    "Romania" : "Rumänien",
+    "Serbia" : "Serbien",
+    "Russian Federation" : "Russian Federation",
+    "Rwanda" : "Rwanda",
+    "Saudi Arabia" : "Saudi Arabia",
+    "Solomon Islands" : "Salomonöarna",
+    "Seychelles" : "Seychellerna",
+    "Sudan" : "Sudan",
+    "Sweden" : "Sverige",
+    "Singapore" : "Singapore",
+    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension and Tristan da Cunha",
+    "Slovenia" : "Slovenien",
+    "Svalbard and Jan Mayen" : "Svalbard and Jan Mayen",
+    "Slovakia" : "Slovakien",
+    "Sierra Leone" : "Sierra Leone",
+    "San Marino" : "San Marino",
+    "Senegal" : "Senegal",
+    "Somalia" : "Somalia",
+    "Suriname" : "Surinam",
+    "South Sudan" : "South Sudan",
+    "Sao Tome and Principe" : "Sao Tome and Principe",
+    "El Salvador" : "El Salvador",
+    "Sint Maarten (Dutch part)" : "Sint Maarten (Dutch part)",
+    "Syrian Arab Republic" : "Syrian Arab Republic",
+    "Turks and Caicos Islands" : "Turks- och Caicosöarna",
+    "Chad" : "Chad",
+    "French Southern Territories" : "Franska södra territorierna",
+    "Togo" : "Togo",
+    "Thailand" : "Thailand",
+    "Tajikistan" : "Tadzjikistan",
+    "Tokelau" : "Tokelau",
+    "Timor-Leste" : "Timor-Leste",
+    "Turkmenistan" : "Turkmenistan",
+    "Tunisia" : "Tunisien",
+    "Tonga" : "Tonga",
+    "Turkey" : "Turkiet",
+    "Trinidad and Tobago" : "Trinidad och Tobago",
+    "Tuvalu" : "Tuvalu",
+    "Tanzania, United Republic of" : "Tanzania, United Republic of",
+    "Ukraine" : "Ukraina",
+    "Uganda" : "Uganda",
+    "United States Minor Outlying Islands" : "United States Minor Outlying Islands",
+    "United States of America" : "United States of America",
+    "Uruguay" : "Uruguay",
+    "Uzbekistan" : "Uzbekistan",
+    "Holy See" : "Holy See",
+    "Saint Vincent and the Grenadines" : "Saint Vincent and the Grenadines",
+    "Viet Nam" : "Viet Nam",
+    "Vanuatu" : "Vanuatu",
+    "Wallis and Futuna" : "Wallis and Futuna",
+    "Samoa" : "Samoa",
+    "Yemen" : "Yemen",
+    "Mayotte" : "Mayotte",
+    "South Africa" : "Sydafrika",
+    "Zambia" : "Zambia",
+    "Zimbabwe" : "Zimbabwe",
     "Invalid date, date format must be YYYY-MM-DD" : "Felaktigt datum, datumformat måste vara ÅÅÅÅ-MM-DD",
     "Conversation not found" : "Konversationen hittades inte",
     "Path is already shared with this room" : "Sökvägen är redan delad med detta rum",
@@ -178,6 +415,15 @@ OC.L10N.register(
     "All messages" : "Alla meddelanden",
     "@-mentions only" : "@-mentions only",
     "Off" : "Av",
+    "Language" : "Språk",
+    "Country" : "Land",
+    "Status" : "Status",
+    "Created at" : "Skapad",
+    "Pending" : "Avvaktar",
+    "Error" : "Fel",
+    "Blocked" : "Blockerar",
+    "Active" : "Aktiv",
+    "Expired" : "Utgånget",
     "Signaling server URL" : "Signalerar serverwebbadress",
     "Validate SSL certificate" : "Validera SSL-certifikat",
     "Delete this server" : "Ta bort denna server",
@@ -216,6 +462,7 @@ OC.L10N.register(
     "Share a single window" : "Dela ett fönster",
     "Show your screen" : "Visa din skärm",
     "Stop screensharing" : "Stoppa skärmdelning",
+    "Dismiss" : "Avfärda",
     "No audio" : "Inget ljud",
     "Mute audio (m)" : "Ljud av (m)",
     "Unmute audio (m)" : "Ljud på (m)",
@@ -278,7 +525,6 @@ OC.L10N.register(
     "Copy conversation link" : "Kopiera konversationslänk",
     "Error while creating the conversation" : "Fel uppstod när konversationen skulle skapas",
     "Link copied to the clipboard!" : "Länken kopierad till urklipp!",
-    "Error" : "Fel",
     "Create a new group conversation" : "Skapa en ny gruppkonversation",
     "Password protect" : "Lösenordsskydda",
     "Add participants" : "Lägg till deltagare",
@@ -333,7 +579,6 @@ OC.L10N.register(
     "Start call" : "Starta samtal",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk uppdaterades, du måste ladda om sidan innan du kan starta eller gå med i ett samtal.",
     "You will be able to join the call only after a moderator starts it." : "Du kommer att kunna gå med i samtalet först när en moderator startar det.",
-    "Dismiss" : "Avfärda",
     "Toggle fullscreen" : "Växla helskärm",
     "Go to file" : "Gå till fil",
     "Rename conversation" : "Byt namn på konversation",
