@@ -59,6 +59,7 @@ OC.L10N.register(
     "{user} invited you to a group conversation: {call}" : "{user} đã mời bạn tham gia cuộc trò chuyện nhóm: {call}",
     "{user} wants to talk with you" : "{user} muốn nói chuyện với bạn",
     "A group call has started in {call}" : "Một cuộc gọi nhóm đã được thực hiện trong {call}",
+    "Open settings" : "Mở thiết đặt",
     "Invalid date, date format must be YYYY-MM-DD" : "Định dạng ngày không hợp lệ phải là YYYY-MM-DD",
     "Conversation not found" : "Không tìm thấy cuộc hội thoại",
     "Path is already shared with this room" : "Đường dẫn đã được chia sẻ với phòng này",
@@ -74,6 +75,13 @@ OC.L10N.register(
     "Disabled" : "Tắt",
     "Users" : "Người dùng",
     "Name" : "Tên",
+    "Language" : "Ngôn ngữ",
+    "Country" : "Quốc gia",
+    "Status" : "Trạng thái",
+    "Created at" : "Được tạo ra vào lúc",
+    "Pending" : "Đang dừng",
+    "Error" : "Lỗi",
+    "Blocked" : "Bị chặn",
     "Signaling server URL" : "URL máy chủ đăng ký",
     "Validate SSL certificate" : "Xác thực chứng chỉ SSL",
     "Saved" : "Đã lưu",
@@ -93,6 +101,7 @@ OC.L10N.register(
     "Share this link to invite others!" : "Chia sẻ liên kết này để mời những người khác!",
     "Show your screen" : "Hiện màn hình của bạn",
     "Stop screensharing" : "Ngừng chia sẽ màn hình",
+    "Dismiss" : "Bỏ qua",
     "No audio" : "Không có âm thanh",
     "Mute audio (m)" : "Tắt âm thành (m)",
     "Unmute audio (m)" : "Mở âm thanh (m)",
@@ -119,7 +128,6 @@ OC.L10N.register(
     "Loading" : "Đang tải",
     "Groups" : "Nhóm",
     "Circles" : "Vòng kết nối",
-    "Error" : "Lỗi",
     "Password protect" : "Mật khẩu bảo vệ",
     "Back" : "Quay lại",
     "Close" : "Đóng",
@@ -142,13 +150,13 @@ OC.L10N.register(
     "Settings" : "Thiết lập",
     "Edit" : "Chỉnh sửa",
     "Start call" : "Bắt đầu cuộc gọi",
-    "Dismiss" : "Bỏ qua",
     "Rename conversation" : "Đổi tên cuộc đàm thoại",
     "Share link" : "Chia sẽ liên kết",
     "Password protection" : "Password protection",
     "Enter a password" : "Nhập mật khẩu",
     "Exit fullscreen (f)" : "Thoát chế độ toàn màn hình (f)",
     "Fullscreen (f)" : "Toàn màn hình (f)",
+    "Grid view" : "Xem dạng Lưới",
     "Join a conversation or start a new one" : "Tham gia cuộc trò chuyện hoặc bắt đầu một cuộc trò chuyện mới",
     "Access to microphone & camera is only possible with HTTPS" : "Chỉ có thể truy cập micrô và máy ảnh bằng HTTPS",
     "Please move your setup to HTTPS" : "Vui lòng di chuyển thiết lập của bạn sang HTTPS",
