@@ -1,4 +1,5 @@
 <?php
+
 declare(strict_types=1);
 /**
  * @author Joachim Bauch <mail@joachim-bauch.de>
@@ -29,6 +30,7 @@ use OCA\Talk\Chat\ChatManager;
 use OCA\Talk\Chat\Command\Listener as CommandListener;
 use OCA\Talk\Chat\Parser\Listener as ParserListener;
 use OCA\Talk\Chat\SystemMessage\Listener as SystemMessageListener;
+use OCA\Talk\Collaboration\Collaborators\Listener as CollaboratorsListener;
 use OCA\Talk\Collaboration\Resources\ConversationProvider;
 use OCA\Talk\Collaboration\Resources\Listener as ResourceListener;
 use OCA\Talk\Config;
@@ -48,6 +50,7 @@ use OCA\Talk\PublicShareAuth\Listener as PublicShareAuthListener;
 use OCA\Talk\PublicShareAuth\TemplateLoader as PublicShareAuthTemplateLoader;
 use OCA\Talk\Room;
 use OCA\Talk\Settings\Personal;
+use OCA\Talk\Share\Listener as ShareListener;
 use OCA\Talk\Share\RoomShareProvider;
 use OCA\Talk\Signaling\Listener as SignalingListener;
 use OCP\AppFramework\App;
@@ -60,10 +63,8 @@ use OCP\Security\CSP\AddContentSecurityPolicyEvent;
 use OCP\Security\FeaturePolicy\AddFeaturePolicyEvent;
 use OCP\Settings\IManager;
 
-
 class Application extends App {
-
-	const APP_ID = 'spreed';
+	public const APP_ID = 'spreed';
 
 	public function __construct(array $urlParams = []) {
 		parent::__construct(self::APP_ID, $urlParams);
@@ -99,8 +100,10 @@ class Application extends App {
 		RoomShareProvider::register($dispatcher);
 		SignalingListener::register($dispatcher);
 		CommandListener::register($dispatcher);
+		CollaboratorsListener::register($dispatcher);
 		ResourceListener::register($dispatcher);
 		ChangelogListener::register($dispatcher);
+		ShareListener::register($dispatcher);
 		Operation::register($dispatcher);
 
 		$dispatcher->addServiceListener(AddContentSecurityPolicyEvent::class, Listener\CSPListener::class);
@@ -135,7 +138,7 @@ class Application extends App {
 	}
 
 	protected function registerNavigationLink(IServerContainer $server): void {
-		$server->getNavigationManager()->add(function() use ($server) {
+		$server->getNavigationManager()->add(function () use ($server) {
 			/** @var Config $config */
 			$config = $server->query(Config::class);
 			$user = $server->getUserSession()->getUser();
@@ -151,7 +154,7 @@ class Application extends App {
 	}
 
 	protected function registerRoomActivityHooks(IEventDispatcher $dispatcher): void {
-		$listener = function(ChatEvent $event) {
+		$listener = function (ChatEvent $event) {
 			$room = $event->getRoom();
 			/** @var ITimeFactory $timeFactory */
 			$timeFactory = $this->getContainer()->query(ITimeFactory::class);
@@ -163,7 +166,7 @@ class Application extends App {
 	}
 
 	protected function registerChatHooks(IEventDispatcher $dispatcher): void {
-		$listener = function(RoomEvent $event) {
+		$listener = function (RoomEvent $event) {
 			/** @var ChatManager $chatManager */
 			$chatManager = $this->getContainer()->query(ChatManager::class);
 			$chatManager->deleteMessages($event->getRoom());
